@@ -525,7 +525,9 @@ class RecentCallsView(object):
 		self._onRecentviewRowActivatedId = 0
 
 		textrenderer = gtk.CellRendererText()
-		self._recentviewColumn = gtk.TreeViewColumn("Calls", textrenderer, text=1)
+		self._recentviewColumn = gtk.TreeViewColumn("Calls")
+		self._recentviewColumn.pack_start(textrenderer, expand=True)
+		self._recentviewColumn.add_attribute(textrenderer, "text", 1)
 		self._recentviewColumn.set_sizing(gtk.TREE_VIEW_COLUMN_FIXED)
 
 	def enable(self):
@@ -614,7 +616,7 @@ class ContactsView(object):
 		self._contactsview = widgetTree.get_widget("contactsview")
 
 		self._contactColumn = gtk.TreeViewColumn("Contact")
-		displayContactSource = True
+		displayContactSource = False
 		if displayContactSource:
 			textrenderer = gtk.CellRendererText()
 			self._contactColumn.pack_start(textrenderer, expand=False)
@@ -736,8 +738,8 @@ class ContactsView(object):
 			finally:
 				gtk.gdk.threads_leave()
 		for contactId, contactName in contacts:
-			contactType = (addressBook.contact_source_short_name(contactId),)
-			self._contactsmodel.append(contactType + (contactName, "", contactId) + ("",))
+			contactType = (addressBook.contact_source_short_name(contactId), )
+			self._contactsmodel.append(contactType + (contactName, "", contactId) + ("", ))
 
 		# restart the treeview data rendering
 		self._contactsview.set_model(self._contactsmodel)
